splitbindingarray

Function splitbindingarray 

pub fn splitbindingarray(
    in_spv: &[u32],
    corrections: &mut Option<CorrectionMap>,
) -> Result<Vec<u32>, ()>
Perform the operation on a Vec<u32>. Use u8_slice_to_u32_vec to convert a &[u8] into a Vec<u32> Either update the existing corrections or create a new one.

Assumed SPIR-V properties for this patch:

TODO:

  • No nested
  • No additional capabilities (SparseResidency or ImageQuery)

wgpu Properties:

  • The only opaque types that can be in an array are OpTypeImage and OpTypeSampler

SPIR-V Properties (These should always be true):

  • No opaque types in structures
  • All UBOs and SSBO hold a structure and therefore are accessed with OpAccessChain* first.